                  VARIETY:  THE SPICE OF LOGIC

                           Ann Tinsley

     There can be no doubt that Aristotle was a genius of the 
highest order.  Among other accomplishments, he created the 
world's first system of logic.  For over two thousand years his 
categorical logic has stood as one of the most remarkable 
inventions of the human mind.  But controversies have swirled 
around this system from the outset.  Numerous competitors have 
emerged, each touted by ardent supporters.  Even today the field 
of categorical logic teems with controversy and contrasting 
approaches.  This unsettled state of affairs, however, is not 
unusual in logic.  Contrary to popular belief, logic is an 
incredibly dynamic discipline.  Having grown astronomically since 
Aristotle, logic is still expanding.  And since logic is now 
closely linked to computer technology, the expansion is sure 
to continue.

     To spark your curiosity about categorical logic, I will take 
you on a tour.  First, we will attend a presentation by Samuel 
Pescay, who contends that Aristotle's approach to categorical 
reasoning is vastly superior to the approaches that enjoy the 
greatest popularity today.  Then we will visit several sites where  
you can play logic games and obtain hands-on experience with  
several approaches.  Along the way, I will help you discover 
the benefits of Aristotle's system, for which I have profound 
respect.  But unlike Pescay, I will celebrate the variety of 
available approaches.  Each strategy, I contend, in its own way 
enriches our understanding of categorical reasoning, one of the 
most important forms of inference the human mind employs.

     PESCAY'S POSITION.  Let us begin by talking about why 
Pescay is so enthusiastic about Aristotle's approach to categorical 
reasoning.  If you aren't already familiar with Pescay's view, 
select the filename ARISTOTL.IRC and click the Display button. 
After perusing his essay, return to this essay by clicking
"Variety:  The Spice of Logic" on the Tours screen or the Game- 
Master screen.

     THE STANDARD APPROACH.  Pescay builds a strong case 
for the Aristotelian approach.  He demonstrates its power, unity, 
and capacity to help us discover valid conclusions.  But before we 
can assess his claim that it is the best strategy, we need to look 
at the alternatives.  We'll explore the Validity-requirements 
Game, which employs one of the standard approachs.  I suggest you 
experiment briefly with the first two levels of the game.  (When you 
have finished, use the ESC key to exit and return to this place in 
the tour.)  To access the game, select Game D and click Display.

     PROS AND CONS.  As you no doubt noticed, the standard 
system excels in the detection of invalidity.  In particular, it 
helps to know that at least one premise must be positive, that a 
negative premise requires a negative conclusion, and that a 
negative conclusion requires a negative premise.  But Pescay 
could point out that Aristotle himself used his system to 
establish these and many other useful facts about categorical 
inferences.  The standard approach, in contrast, simply lays them 
down as requirements.  Furthermore, the standard system falters 
when it comes to detection of validity.  We can apply it only to 
completed inferences, and we must run through the list of all 
four requirements to determine validity.  When it comes to 
searching for conclusions that follow from given premises, the 
system is inferior to Aristotle's "natural deduction" approach.

     The genuinely-distinctive aspects of the standard system 
center on the notion of distribution.  It is precisely this 
notion, however, that has drawn the fiercest flak.  Critics have 
contended that the theory of distribution is obscure at best and 
incoherent at worst.  Perhaps the most vexing problem concerns 
such statements as "Some dogs are not pets"--explanations of why 
the term "pets" is distributed are typically somewhat strained.  
In practice the system tends to encourage rote memorization of 
which terms are distributed and which are not.

     Defenders of the standard system can argue that Pescay's 
comparisons are misleading.  The Aristotelian system requires us 
to use numerous auxiliary rules in addition to the Inclusion and 
Exclusion principles, something which not only complicates the 
search for valid conclusions, but makes success in determining 
invalidity dependent upon our reasoning skills.  Furthermore, 
standard-system advocates could contend that, whereas the 
Aristotelian system employs plausible-but-unproven principles, 
the notion of distribution can help us establish the soundness of 
the principles.

     COMPARING APPROACHES.  Let's now go to the 
Categorical-rules Game, which employs an Aristotelian approach.  
While working with this game, reflect on the strengths and drawbacks 
of each of the two contrasting strategies.  Select Game E and click 
Display.

     MISSING PIECES.  Now that you have had a chance to 
practice using both approaches, I will take you to the Inference- 
completion Game, which lets you employ either method.  In this 
game you work with incomplete inferences, attempting to supply 
missing premises and conclusions.  Suggestion:  Try to generate 
missing conclusions before you look at the choices provided.  
This will help you test Pescay's claim that Aristotle's approach 
facilitates the quest for conclusions.  While you are at it, try 
to determine which approach provides the most assistance with the 
related task of supplying missing premises.  Select Game G and 
click Display.

     INTERMEDIATE QUANTIFIERS.  As Pescay has noted, the 
Aristotelian approach, unlike the standard strategy, can be 
deployed to handle intermediate quantifiers such as "a few," 
"many," "most," and "almost all."  To give you an opportunity to 
experiment with this capability, I will take you to the 
Proportional-rules Game.  Secect Game F and click Display.

     MY POSITION.  I share Pescay's admiration for the 
Aristotelian approach.  As he has ably demonstrated, it exhibits 
amazing power and unity.  Moreover, it helps us discover valid 
conclusions, not just evaluate inferences which already contain 
conclusions.  But in my opinion the standard system is extremely 
useful for assessing completed inferences not involving 
intermediate quantifiers.  Consider, by way of comparison, the 
situation in propositional logic.  Rules of propositional 
inference, such as Modus Ponens, Modus Tollens, and Disjunctive 
Syllogism, are invaluable for generating valid conclusions.  But 
truth tables are often more effective for definitively 
determining the validity or invalidity of completed inferences 
involving truth-functional relationships.  To help you see the 
analogy, I will first take you to the Propositional-rules Game, 
and later to the Truth-table Game.  Select Game H and click 
Display.

     As you have seen, the Propositional Logic rules work like 
the principles of Inclusion, Exclusion, and Preclusion, enabling 
us to generate valid conclusions.  Let's now go to the 
Truth-table Game, which provides an effective, "mechanical" way 
of evaluating truth-functional inferences.  Select Game M and 
click Display.

     Propositional-inference rules and truth tables each have 
useful roles to play.  Neither is preferable for all purposes.  
Similarly, the Aristotelian approach to categorical reasoning is 
superior to the standard system for some but not all purposes.  
Each system should be valued for what it does best.  That said, I 
must admit that I sympathize with Pescay's concern about the 
widespread neglect of the Aristotelian approach, and I hope that 
he succeeds in generating more interest in it.

     EULER DIAGRAMS.  In keeping with my overall aim of 
celebrating the variety of approaches at our disposal, I will 
take you to a few more interesting sites before the tour ends.  
In addition to the Aristotelian and the standard approaches, 
several graphically-oriented systems have been devised.  These 
methods not only help us discover conclusions, but enable us to 
picture logical relationships!  (I personally find this quite 
helpful and enjoyable.)  I will now take you to the Euler-diagram 
Game.  Select Game C and click Display.

     VENN DIAGRAMS.  I will give you the opportunity to work 
with the Venn-diagram approach.  First, you will see how the diagrams 
work with inferences not involving intermediate quantifiers. 
Select Game A and click Display.

     As the final step in the tour, let's see how the Venn 
diagram strategy can be adapted to handle intermediate 
quantifiers.  Select Game B and click Display.

     I hope you have enjoyed the tour, and I hope you can 
now understand why I think that employing a variety of 
approaches enlivens explorations of categorical reasoning and 
deepens understanding of this fundamental form of inference.
