                  CHAOS, FRACTALS, AND FREEDOM

                          Alison Gilbert

     In Greek mythology, everything that exists--even the 
gods--emerged from the primordial, formless state of Chaos.  
Envisioning an all-encompassing cosmos, ancient Greek thinkers 
created remarkable philosophical systems that endowed the world 
with unprecedented intelligibility.  But their visions of 
universal order fueled determinisms that left little conceptual 
space for human freedom.  The more their theorizing enhanced the 
comprehensibility and predictability of events, the more it made 
everything that will come to be seem predestined.

     Contemporary chaos theorists envision a universe 
permeated by clusters of disorder.  Systematic investigation 
of chaotic systems is today an integral part of the new science 
of complexity:  the study of the principles of order underlying 
all dynamical dimensions of reality, from purely physical 
systems through ecosystems to social systems.  Perhaps this 
new vision can help us in our own efforts to understand freedom.

     CHAOS AND FRACTALS.  Chaotic systems are intrinsically 
unpredictable because they exhibit extreme sensitivity to initial 
conditions.  For example, undetectable movements of minute 
quantities of water vapor high above a tropical sea can determine 
whether or not a massive hurricane will eventually develop.

     With the aid of a new mathematical system called fractal 
geometry, scientists are developing a better understanding of the 
chaotic aspects of complex systems.  Unlike Euclidian geometry, 
which deals only with whole-number dimensions (1, 2, 3, etc.), 
fractal geometry can represent fractional dimensions as well 
(e.g., 1.4, 2.3, 2.8).  Chaos theorists exploit this enhanced 
representational power to reveal concealed regularities in 
systems that change over time.  As dynamical systems develop, 
feedback processes amplify minuscule changes and generate effects 
ranging from the highly predictable to the utterly chaotic.  The 
systems exhibit holistic fractal patterns, called attractors, 
which often afford surprising degrees of high-level 
predictability.

     Through the lens of fractal geometry, hidden order appears 
in vast portions of the universe.  Intelligible patterns emerge 
in the seemingly random shapes of coastlines, mountain ranges, 
geological faults, tree branches, blood vessels, and nerve-cell 
dendrites.  Otherwise-invisible regularities are detected in 
turbulent fluids, stock-market fluctuations, brain waves, and 
movements of galaxies.  With the help of computers, simple 
equations can be deployed to generate endlessly variable fractal 
images of incredible complexity and astonishing beauty.  To see 
one of my favorites, select the filename IMAGE4.JPG and click 
the Display button.

     Fractals exhibit self-similarity--individual parts resemble 
the whole.  For example, the famous Mandelbrot set, a 
fascinating, infinitely-varied mathematical object, takes the 
form of an apple-shaped figure sporting numerous circular buds, 
each of which has similar buds of its own.  To see a picture of 
the set, select the filename IMAGE5.JPG and click Display.

     Let's zoom into one of the areas where two buds meet.  
Myriad additional buds appear, each of which could be enlarged to 
reveal similar details.  Select the filename IMAGE1.JPG and 
click Display.

     While scientists are making increasing use of fractal 
geometry to study the behavior of dynamical systems, artists have 
begun to exploit the aesthetic potential of fractals.  Indeed, 
the first three images above were created by an artist, Lee H. 
Skinner, using a free software program called Fractint.  To see 
an extensive collection of fractal images made with this program, 
select the URL:

	http://www.nahee.com/spanky/www/fractint/fract-gal.html

and click Display.

     CHAOS AND INDETERMINACY.  Chaos theory enables us 
to make sense of disorder without discarding the hard-won 
deterministic theories that help us comprehend and control so 
much of reality.  Systems involving chaos can be inherently 
unpredictable without being indeterministic.  For example, 
precise weather predictions are impossible because of extreme 
sensitivity to undetectable initial conditions, whereas precise 
predictions of the decay of uranium atoms are impossible because 
of indeterminacy--two identical atoms under identical conditions 
may decay at different times.  I want to argue that the 
distinction between chaos and indeterminacy can help us 
understand free will.

     Just as ancient Greek thinkers wrestled with the conflict 
between freedom and determinism, so we struggle to preserve our 
sense of ourselves as free agents living in a world governed by 
blind laws of nature, laws which account for the very existence 
of our bodies and our minds.  The difficulty of establishing that 
free will is not an illusion is ably discussed by Anthony Murray 
in a Dymamic Essay entitled "The Free Will Problem."  After 
critiquing the main positions on the free-will issue, Murray 
develops a promising view of his own.  But he ends with the frank 
admission that his theory is confronted with a formidable 
problem -- it appears to clash with a law of nature.  To access 
his essay, select the filename FREEWILL.IRC and click Display.
(After perusing his essay, return to this essay by clicking
Chaos, Fractals and Freedom on the Tours screen.)

     CHAOS AND FREEDOM.  As you have seen, Murray rightly 
worries that the indeterminacy he ascribes to human decision 
making may be incompatible with the law of conservation of matter 
and energy.  (As Murray no doubt realizes, appeals to quantum 
theory to solve the problem would be ad hoc.  There is no good 
evidence that mental events and their neurophysiological 
correlates are subject to the indeterminacy found in certain 
micro-level processes, such as the spontaneous decay of 
radioactive atoms.)

     In my view Murray should invoke chaos instead of 
indeterminacy to account for the elements of spontaneity and 
unpredictability characteristic of decision-making processes.  
With this change, the theory would no longer clash with 
deterministic laws of nature, for chaotic states are 
intrinsically unpredictable without being indeterministic.

     CHAOS-ORIENTED COMPATIBILISM.  From the perspective 
of chaos theory, the mind-brain is a dynamical system involving 
intricate feedback processes.  Myriad fractal forms incessantly 
wax and wane, intermingled with chaotic states.  There is no 
need to posit indeterminacy to account for the elements of 
unpredictability associated with the decision-making process.

     When you are involved in making a decision, the process 
appears "from the inside" as rational deliberation accompanied by 
feelings of spontaneity and unpredictability.  If you were to 
observe the process "from the outside" via computer-generated 
videos of electroencephalographic (EEG) data produced by your 
brain, you would see attractors emerging and fading against a 
background of chaos.  Paul Rapp, a neuroscientist at the Medical 
College of Pennsylvania, was moved by his experiences observing 
subjects engaged in mental activity:

     "The emotional impact of electroencephalographic images 
is, for me, rather considerable.  For the first time we are able to 
see the changes in the geometry of EEG activity that occur as the 
result of human cognitive activity.  Before these attractors had 
been constructed, I didn't know what to expect.  I expected to 
see something very boring that did not significantly change as 
the subject began to think.  The moment these structures flooded 
onto the screen and began to rotate, I knew that I was seeing 
something very extraordinary."

--------------------------------------------------------------- 
Note:  The above quotation appears on pages 31-32 of a book I 
highly recommend for further reading:  Fractals:  The Patterns 
of Chaos, by John Briggs (Simon & Schuster, 1992).